@@ -1,7 +1,7 @@
 package Bencher::Scenarios::Perinci;
 
-our $DATE = '2016-01-05'; # DATE
-our $VERSION = '0.03'; # VERSION
+our $DATE = '2016-06-26'; # DATE
+our $VERSION = '0.04'; # VERSION
 
 use 5.010001;
 use strict;
@@ -22,7 +22,7 @@ Bencher::Scenarios::Perinci - A collection of bencher scenarios to benchmark Per
 
 =head1 VERSION
 
-This document describes version 0.03 of Bencher::Scenarios::Perinci (from Perl distribution Bencher-Scenarios-Perinci), released on 2016-01-05.
+This document describes version 0.04 of Bencher::Scenarios::Perinci (from Perl distribution Bencher-Scenarios-Perinci), released on 2016-06-26.
 
 =head1 HOMEPAGE
 
@@ -40,6 +40,11 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+For Perinci::CmdLine-related benchmarks, please see the
+L<Bencher::Scenarios::PerinciCmdLine> distribution.
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
